@@ -21,7 +21,7 @@
 #ifndef MixDevice_h
 #define MixDevice_h
 
-#include "config.h"
+#include <config.h>
 
 #if defined(HAVE_STD_SHARED_PTR)
 #include <memory>
