@@ -167,7 +167,7 @@ void gradient( QPainter &p, bool hor, const QRect &rect, const QColor &ca, const
    int rDiff, gDiff, bDiff;
    int rca, gca, bca, rcb, gcb, bcb;
 
-   register int x, y;
+   int x, y;
 
    if ((rect.width()<=0) || (rect.height()<=0)) return;
 
@@ -175,9 +175,9 @@ void gradient( QPainter &p, bool hor, const QRect &rect, const QColor &ca, const
    gDiff = (gcb = cb.green()) - (gca = ca.green());
    bDiff = (bcb = cb.blue())  - (bca = ca.blue());
 
-   register int rl = rca << 16;
-   register int gl = gca << 16;
-   register int bl = bca << 16;
+   int rl = rca << 16;
+   int gl = gca << 16;
+   int bl = bca << 16;
 
    int rcdelta = ((1<<16) / ((!hor) ? rect.height() : rect.width())) * rDiff;
    int gcdelta = ((1<<16) / ((!hor) ? rect.height() : rect.width())) * gDiff;
@@ -187,7 +187,7 @@ void gradient( QPainter &p, bool hor, const QRect &rect, const QColor &ca, const
    // would make it slow
    if (!hor)
    {
-      for ( y = rect.top(); y <= rect.bottom(); y++ ) {
+      for ( y = rect.top(); y <= rect.bottom(); ++y ) {
          rl += rcdelta;
          gl += gcdelta;
          bl += bcdelta;
@@ -197,7 +197,7 @@ void gradient( QPainter &p, bool hor, const QRect &rect, const QColor &ca, const
       }
    } else
    {
-      for( x = rect.left(); x <= rect.right(); x++) {
+      for( x = rect.left(); x <= rect.right(); ++x) {
          rl += rcdelta;
          gl += gcdelta;
          bl += bcdelta;
@@ -331,7 +331,7 @@ void KSmallSlider::wheelEvent( QWheelEvent * qwe)
     emit valueChanged(newVal);
     qwe->accept(); // Accept the event
 
-    // Hint: Qt autmatically triggers a valueChange() when we do setValue()
+    // Hint: Qt automatically triggers a valueChange() when we do setValue()
 }
 
 
